@@ -3,15 +3,18 @@ construct_runners_check_args <- function(os,
                                          r,
                                          cont){
   if(!all(os %in% names(bioc))){
-    stp <- paste("All `os` must be names of elements in `bioc_version`.")
+    stp <- paste(
+      "All `os` must be names of elements in `bioc_version` argument.")
     stop(stp)
   }
   if(!all(os %in% names(r))){
-    stp <- paste("All `os` must be names of elements in `r`.")
+    stp <- paste(
+      "All `os` must be names of elements in `r` argument.")
     stop(stp)
   }
   if(!all(os %in% names(cont))){
-    stp <- paste("All `os` must be names of elements in `cont`.")
+    stp <- paste(
+      "All `os` must be names of elements in `cont` argument.")
     stop(stp)
   }
 }
\ No newline at end of file
